@@ -1,16 +1,18 @@
 package WebService::Hexonet;
 
-use 5.026000;
+use 5.026_000;
 use strict;
 use warnings;
 use WebService::Hexonet::Connector;
 
-our $VERSION = '1.12';
+use version 0.9917; our $VERSION = version->declare('v2.0.0');
 
 1;
 
 __END__
 
+=pod
+
 =head1 NAME
 
 WebService::Hexonet - Namespace package for modules provided by L<HEXONET|https://www.hexonet.net/>.
@@ -26,18 +28,16 @@ Up to now we provide the following modules:
 
 =over 4
 
-=item L<WebService::Hexonet::Connector> - Connector Library for our Backend API.
+=item L<WebService::Hexonet::Connector|WebService::Hexonet::Connector> - Connector Library for our Backend API.
 
 =back
 
+=head1 LICENSE AND COPYRIGHT
+
+This program is licensed under the L<MIT License|https://raw.githubusercontent.com/hexonet/perl-sdk/master/LICENSE>.
+
 =head1 AUTHOR
 
-Hexonet GmbH
+L<HEXONET GmbH|https://www.hexonet.net>
 
-L<https://www.hexonet.net>
-
-=head1 LICENSE
-
-MIT
-
-=cut
\ No newline at end of file
+=cut
